# -*- coding: utf-8 -*-

# Copyright (C) 2005 Osmo Salomaa
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

import gaupol

from gi.repository import Gtk
from unittest.mock import patch


class TestHelpAgent(gaupol.TestCase):

    def setup_method(self, method):
        self.application = self.new_application()

    def test__on_browse_documentation_activate(self):
        self.application.get_action("browse-documentation").activate()

    def test__on_report_a_bug_activate(self):
        self.application.get_action("report-a-bug").activate()

    @patch("gaupol.util.flash_dialog", lambda *args: Gtk.ResponseType.DELETE_EVENT)
    def test__on_view_about_dialog_activate(self):
        self.application.get_action("view-about-dialog").activate()



# -*- coding: utf-8 -*-

# Copyright (C) 2005 Osmo Salomaa
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

import aeidon


class TestClipboardAgent(aeidon.TestCase):

    def setup_method(self, method):
        self.project = self.new_project()

    @aeidon.deco.reversion_test
    def test_cut_texts(self):
        self.project.cut_texts((0, 2), aeidon.documents.MAIN)

    @aeidon.deco.reversion_test
    def test_paste_texts(self):
        self.project.copy_texts((0, 1), aeidon.documents.TRAN)
        self.project.paste_texts(2, aeidon.documents.MAIN)

    @aeidon.deco.reversion_test
    def test_paste_texts__new(self):
        nsubtitles = len(self.project.subtitles)
        self.project.copy_texts((0, 1), aeidon.documents.TRAN)
        self.project.paste_texts(nsubtitles-1, aeidon.documents.MAIN)
        assert len(self.project.subtitles) == nsubtitles + 1



# -*- coding: utf-8 -*-

# Copyright (C) 2005 Osmo Salomaa
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

import gaupol

from gi.repository import Gtk
from unittest.mock import patch


class TestEditAgent(gaupol.TestCase):

    def setup_method(self, method):
        self.application = self.new_application()

    def test__on_clear_texts_activate(self):
        page = self.application.get_current_page()
        page.view.set_focus(0, page.view.columns.MAIN_TEXT)
        page.view.select_rows((0,1,2))
        self.application.get_action("clear-texts").activate()

    def test__on_copy_texts_activate(self):
        page = self.application.get_current_page()
        page.view.set_focus(0, page.view.columns.MAIN_TEXT)
        page.view.select_rows((0,1,2))
        self.application.get_action("copy-texts").activate()

    def test__on_cut_texts_activate(self):
        page = self.application.get_current_page()
        page.view.set_focus(0, page.view.columns.MAIN_TEXT)
        page.view.select_rows((0,1,2))
        self.application.get_action("cut-texts").activate()
        assert page.project.subtitles[0].main_text == ""
        assert page.project.subtitles[1].main_text == ""
        assert page.project.subtitles[2].main_text == ""

    def test__on_edit_next_value_activate(self):
        page = self.application.get_current_page()
        page.view.set_focus(0, page.view.columns.MAIN_TEXT)
        self.application.get_action("edit-next-value").activate()

    def test__on_edit_preferences_activate(self):
        self.application.get_action("edit-preferences").activate()
        self.application.get_action("edit-preferences").activate()

    def test__on_edit_value_activate(self):
        page = self.application.get_current_page()
        page.view.set_focus(0, page.view.columns.MAIN_TEXT)
        self.application.get_action("edit-value").activate()

    def test__on_end_earlier_activate(self):
        self.application.get_action("end-earlier").activate()
        self.application.get_action("end-earlier").activate()
        self.application.get_action("end-earlier").activate()

    def test__on_end_later_activate(self):
        self.application.get_action("end-later").activate()
        self.application.get_action("end-later").activate()
        self.application.get_action("end-later").activate()

    def test__on_extend_selection_to_beginning_activate(self):
        page = self.application.get_current_page()
        page.view.select_rows((4,5))
        self.application.get_action("extend-selection-to-beginning").activate()
        rows = page.view.get_selected_rows()
        assert rows == tuple(range(0, 6))

    def test__on_extend_selection_to_end_activate(self):
        page = self.application.get_current_page()
        page.view.select_rows((4,5))
        self.application.get_action("extend-selection-to-end").activate()
        rows = page.view.get_selected_rows()
        assert rows == tuple(range(4, len(page.project.subtitles)))

    @patch("gaupol.util.flash_dialog", lambda *args: Gtk.ResponseType.OK)
    def test__on_insert_subtitles_activate(self):
        page = self.application.get_current_page()
        page.view.set_focus(0, page.view.columns.MAIN_TEXT)
        self.application.get_action("insert-subtitles").activate()

    def test__on_invert_selection_activate(self):
        page = self.application.get_current_page()
        page.view.select_rows((0,1,2))
        self.application.get_action("invert-selection").activate()
        rows = page.view.get_selected_rows()
        assert rows == tuple(range(3, len(page.project.subtitles)))
        self.application.get_action("invert-selection").activate()
        rows = page.view.get_selected_rows()
        assert rows == (0,1,2)

    def test__on_merge_subtitles_activate(self):
        page = self.application.get_current_page()
        n = len(page.project.subtitles)
        page.view.set_focus(0, page.view.columns.MAIN_TEXT)
        page.view.select_rows((0,1))
        self.application.get_action("merge-subtitles").activate()
        assert len(page.project.subtitles) == n-1

    def test__on_paste_texts_activate(self):
        page = self.application.get_current_page()
        page.view.set_focus(0, page.view.columns.MAIN_TEXT)
        page.view.select_rows((0,1,2))
        self.application.get_action("copy-texts").activate()
        page.view.set_focus(0, page.view.columns.MAIN_TEXT)
        self.application.get_action("paste-texts").activate()

    def test__on_redo_action_activate(self):
        page = self.application.get_current_page()
        n = len(page.project.subtitles)
        page.project.remove_subtitles((0,))
        self.application.get_action("undo-action").activate()
        self.application.get_action("redo-action").activate()
        assert len(page.project.subtitles) == n-1

    def test__on_remove_subtitles_activate(self):
        page = self.application.get_current_page()
        n = len(page.project.subtitles)
        page.view.select_rows((0,1,2))
        self.application.get_action("remove-subtitles").activate()
        assert len(page.project.subtitles) == n-3

    def test__on_select_all_activate(self):
        page = self.application.get_current_page()
        self.application.get_action("select-all").activate()
        rows = page.view.get_selected_rows()
        assert rows == tuple(range(0, len(page.project.subtitles)))

    def test__on_split_subtitle_activate(self):
        page = self.application.get_current_page()
        n = len(page.project.subtitles)
        page.view.set_focus(0, page.view.columns.MAIN_TEXT)
        self.application.get_action("split-subtitle").activate()
        assert len(page.project.subtitles) == n + 1

    def test__on_start_earlier_activate(self):
        self.application.get_action("start-earlier").activate()
        self.application.get_action("start-earlier").activate()
        self.application.get_action("start-earlier").activate()

    def test__on_start_later_activate(self):
        self.application.get_action("start-later").activate()
        self.application.get_action("start-later").activate()
        self.application.get_action("start-later").activate()

    def test__on_undo_action_activate(self):
        page = self.application.get_current_page()
        n = len(page.project.subtitles)
        page.project.remove_subtitles((0,))
        self.application.get_action("undo-action").activate()
        assert len(page.project.subtitles) == n

    def test_redo(self):
        page = self.application.get_current_page()
        n = len(page.project.subtitles)
        page.project.remove_subtitles((0,))
        self.application.undo()
        self.application.redo()
        assert len(page.project.subtitles) == n-1

    def test_undo(self):
        page = self.application.get_current_page()
        n = len(page.project.subtitles)
        page.project.remove_subtitles((0,))
        self.application.undo()
        assert len(page.project.subtitles) == n



# -*- coding: utf-8 -*-

# Copyright (C) 2005 Osmo Salomaa
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

import aeidon
import gaupol

from gi.repository import Gtk
from unittest.mock import patch


class TestCloseAgent(gaupol.TestCase):

    def run__confirm_close_both(self):
        page = self.application.get_current_page()
        page.project.remove_subtitles((0,))
        with aeidon.util.silent(gaupol.Default):
            self.application.close(page)

    def run__confirm_close_main(self):
        page = self.application.get_current_page()
        page.project.set_text(0, aeidon.documents.MAIN, "")
        with aeidon.util.silent(gaupol.Default):
            self.application.close(page)

    def run__confirm_close_translation(self):
        page = self.application.get_current_page()
        page.project.set_text(0, aeidon.documents.TRAN, "")
        with aeidon.util.silent(gaupol.Default):
            self.application.close(page)

    def setup_method(self, method):
        self.application = self.new_application()

    @patch("gaupol.util.flash_dialog", lambda *args: Gtk.ResponseType.CANCEL)
    @aeidon.deco.silent(gaupol.Default)
    def test_close(self):
        self.application.pages[-1].project.remove_subtitles((0,))
        self.application.close(self.application.pages[-1], confirm=True)

    @patch("gaupol.util.flash_dialog", lambda *args: Gtk.ResponseType.NO)
    @aeidon.deco.silent(gaupol.Default)
    def test_close_all(self):
        for page in self.application.pages:
            page.project.remove_subtitles((0,))
        self.application.close_all()



# -*- coding: utf-8 -*-

# Copyright (C) 2005 Osmo Salomaa
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

import gaupol

from gi.repository import Gtk


class TestTimeEntry(gaupol.TestCase):

    def run_entry(self):
        self.entry.set_text("12:34:56.789")
        window = Gtk.Window()
        window.connect("delete-event", Gtk.main_quit)
        window.set_position(Gtk.WindowPosition.CENTER)
        window.set_default_size(200, 50)
        window.add(self.entry)
        window.show_all()
        Gtk.main()

    def setup_method(self, method):
        self.entry = gaupol.TimeEntry()



# -*- coding: utf-8 -*-

# Copyright (C) 2005 Osmo Salomaa
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

import aeidon
import gaupol
import random

from gi.repository import Gtk


class TestView(gaupol.TestCase):

    def run_view_frame(self):
        self.setup_frame()
        window = Gtk.Window()
        window.connect("delete-event", Gtk.main_quit)
        window.set_position(Gtk.WindowPosition.CENTER)
        window.set_default_size(200, 200)
        window.add(self.view)
        window.show_all()
        Gtk.main()

    def run_view_time(self):
        self.setup_time()
        window = Gtk.Window()
        window.connect("delete-event", Gtk.main_quit)
        window.set_position(Gtk.WindowPosition.CENTER)
        window.set_default_size(200, 200)
        window.add(self.view)
        window.show_all()
        Gtk.main()

    def setup_frame(self):
        self.view = gaupol.View(aeidon.modes.FRAME)
        store = self.view.get_model()
        self.project = self.new_project()
        for i, subtitle in enumerate(self.project.subtitles):
            store.append((i + 1,
                          subtitle.start_frame,
                          subtitle.end_frame,
                          subtitle.duration_frame,
                          subtitle.main_text,
                          subtitle.tran_text))

    def setup_method(self, method):
        random.choice((self.setup_frame, self.setup_time))()
        self.conf = gaupol.conf.editor

    def setup_time(self):
        self.view = gaupol.View(aeidon.modes.TIME)
        store = self.view.get_model()
        self.project = self.new_project()
        for i, subtitle in enumerate(self.project.subtitles):
            store.append((i + 1,
                          subtitle.start_time,
                          subtitle.end_time,
                          subtitle.duration_seconds,
                          subtitle.main_text,
                          subtitle.tran_text))

    def test_select_rows(self):
        self.view.select_rows(())
        assert self.view.get_selected_rows() == ()
        self.view.select_rows((1, 2))
        assert self.view.get_selected_rows() == (1, 2)

    def test_set_focus(self):
        self.view.set_focus(2, None)
        assert self.view.get_focus() == (2, None)
        self.view.set_focus(1, 3)
        assert self.view.get_focus() == (1, 3)
        self.view.set_focus(-1, 4)
        n = len(self.project.subtitles)
        assert self.view.get_focus() == (n-1, 4)



# -*- coding: utf-8 -*-

# Copyright (C) 2005 Osmo Salomaa
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

import aeidon
import gaupol
import os

from gi.repository import Gtk
from gaupol.dialogs.test.test_file import _TestFileDialog


class TestSaveDialog(_TestFileDialog):

    def run_dialog(self):
        self.dialog.run()
        self.dialog.destroy()

    def setup_method(self, method):
        gaupol.conf.file.directory = os.getcwd()
        self.dialog = gaupol.SaveDialog(parent=Gtk.Window(),
                                        title="test",
                                        mode=aeidon.modes.TIME)

        self.dialog.show()

    def test_get_format(self):
        self.dialog.set_format(aeidon.formats.SUBRIP)
        value = self.dialog.get_format()
        assert value == aeidon.formats.SUBRIP

    def test_get_framerate(self):
        self.dialog.set_framerate(aeidon.framerates.FPS_23_976)
        value = self.dialog.get_framerate()
        assert value == aeidon.framerates.FPS_23_976

    def test_get_newline(self):
        self.dialog.set_newline(aeidon.newlines.UNIX)
        value = self.dialog.get_newline()
        assert value == aeidon.newlines.UNIX

    def test__on_response(self):
        self.dialog.response(Gtk.ResponseType.CANCEL)

    def test_set_format(self):
        self.dialog.set_format(aeidon.formats.MICRODVD)
        value = self.dialog.get_format()
        assert value == aeidon.formats.MICRODVD

    def test_set_framerate(self):
        self.dialog.set_framerate(aeidon.framerates.FPS_25_000)
        value = self.dialog.get_framerate()
        assert value == aeidon.framerates.FPS_25_000

    def test_set_name__name__basename(self):
        self.dialog.set_name("test")

    def test_set_name__name__path(self):
        self.dialog.set_name(self.new_subrip_file())

    def test_set_newline(self):
        self.dialog.set_newline(aeidon.newlines.WINDOWS)
        value = self.dialog.get_newline()
        assert value == aeidon.newlines.WINDOWS



# -*- coding: utf-8 -*-

# Copyright (C) 2007 Osmo Salomaa
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

import aeidon

MAIN  = aeidon.documents.MAIN
TRAN  = aeidon.documents.TRAN

FRAME = aeidon.modes.FRAME
TIME  = aeidon.modes.TIME


class TestSubtitle(aeidon.TestCase):

    def setup_method(self, method):
        self.tsub = aeidon.Subtitle()
        self.tsub.mode = TIME
        self.tsub.framerate = aeidon.framerates.FPS_25_000
        self.tsub.start = "00:00:01.000"
        self.tsub.end = "00:00:03.000"
        self.tsub.main_text = "main"
        self.tsub.tran_text = "translation"
        self.fsub = aeidon.Subtitle()
        self.fsub.mode = FRAME
        self.fsub.framerate = aeidon.framerates.FPS_25_000
        self.fsub.start = 100
        self.fsub.end = 300
        self.fsub.main_text = "main"
        self.fsub.tran_text = "translation"

    def test_convert_framerate__frame(self):
        self.fsub.start = 100
        self.fsub.end = 200
        framerate = aeidon.framerates.FPS_23_976
        self.fsub.convert_framerate(framerate)
        assert self.fsub.framerate == framerate
        assert self.fsub.start == 96
        assert self.fsub.end == 192

    def test_convert_framerate__time(self):
        self.tsub.start = "00:00:01.000"
        self.tsub.end = "00:00:02.000"
        framerate = aeidon.framerates.FPS_23_976
        self.tsub.convert_framerate(framerate)
        assert self.tsub.framerate == framerate
        assert self.tsub.start == "00:00:01.043"
        assert self.tsub.end == "00:00:02.085"

    def test_duration__get(self):
        assert self.tsub.duration == "00:00:02.000"
        assert self.fsub.duration == 200

    def test_duration__set_frame(self):
        self.fsub.duration = 500
        assert self.fsub.end_frame == 600
        self.fsub.duration = "00:00:10.000"
        assert self.fsub.end_frame == 350
        self.fsub.duration = 5.0
        assert self.fsub.end_frame == 225

    def test_duration__set_time(self):
        self.tsub.duration = "00:00:10.000"
        assert self.tsub.end_time == "00:00:11.000"
        self.tsub.duration = 500
        assert self.tsub.end_time == "00:00:21.000"
        self.tsub.duration = 10.0
        assert self.tsub.end_time == "00:00:11.000"

    def test_duration_frame__get(self):
        assert self.tsub.duration_frame == 50
        assert self.fsub.duration_frame == 200

    def test_duration_frame__set(self):
        self.fsub.duration_frame = 500
        assert self.fsub.end_frame == 600

    def test_duration_seconds__get(self):
        assert self.tsub.duration_seconds == 2.0
        assert self.fsub.duration_seconds == 8.0

    def test_duration_seconds__set(self):
        self.tsub.duration_seconds = 3.0
        assert self.tsub.end_seconds == 4.0

    def test_duration_time__get(self):
        assert self.tsub.duration_time == "00:00:02.000"
        assert self.fsub.duration_time == "00:00:08.000"

    def test_duration_time__set(self):
        self.tsub.duration_time = "00:00:03.000"
        assert self.tsub.end_time == "00:00:04.000"

    def test_end__get(self):
        assert self.tsub.end == "00:00:03.000"
        assert self.fsub.end == 300

    def test_end__set_frame(self):
        self.fsub.end = 500
        assert self.fsub.end_frame == 500
        self.fsub.end = "00:00:10.000"
        assert self.fsub.end_frame == 250
        self.fsub.end = 5.0
        assert self.fsub.end_frame == 125

    def test_end__set_time(self):
        self.tsub.end = "00:00:10.000"
        assert self.tsub.end_time == "00:00:10.000"
        self.tsub.end = 500
        assert self.tsub.end_time == "00:00:20.000"
        self.tsub.end = 5.0
        assert self.tsub.end_time == "00:00:05.000"

    def test_end_frame__get(self):
        assert self.tsub.end_frame == 75
        assert self.fsub.end_frame == 300

    def test_end_frame__set(self):
        self.fsub.end_frame = 300
        assert self.fsub.end_frame == 300

    def test_end_seconds__get(self):
        assert self.tsub.end_seconds == 3.0
        assert self.fsub.end_seconds == 12.0

    def test_end_seconds__set(self):
        self.tsub.end_seconds = 4.0
        assert self.tsub.end_seconds == 4.0

    def test_end_time__get(self):
        assert self.tsub.end_time == "00:00:03.000"
        assert self.fsub.end_time == "00:00:12.000"

    def test_end_time__set(self):
        self.tsub.end_time = "00:00:04.000"
        assert self.tsub.end_time == "00:00:04.000"

    def test_framerate__get(self):
        assert self.tsub.framerate == aeidon.framerates.FPS_25_000
        assert self.fsub.framerate == aeidon.framerates.FPS_25_000

    def test_framerate__set(self):
        self.tsub.framerate = aeidon.framerates.FPS_29_970
        assert self.tsub.framerate == aeidon.framerates.FPS_29_970

    def test_get_duration(self):
        assert self.tsub.get_duration(TIME) == "00:00:02.000"
        assert self.tsub.get_duration(FRAME) == 50
        assert self.fsub.get_duration(TIME) == "00:00:08.000"
        assert self.fsub.get_duration(FRAME) == 200

    def test_get_end(self):
        assert self.tsub.get_end(TIME) == "00:00:03.000"
        assert self.tsub.get_end(FRAME) == 75
        assert self.fsub.get_end(TIME) == "00:00:12.000"
        assert self.fsub.get_end(FRAME) == 300

    def test_get_start(self):
        assert self.tsub.get_start(TIME) == "00:00:01.000"
        assert self.tsub.get_start(FRAME) == 25
        assert self.fsub.get_start(TIME) == "00:00:04.000"
        assert self.fsub.get_start(FRAME) == 100

    def test_get_text(self):
        assert self.tsub.get_text(MAIN) == "main"
        assert self.tsub.get_text(TRAN) == "translation"

    def test_main_text__get(self):
        assert self.tsub.main_text == "main"
        assert self.fsub.main_text == "main"

    def test_main_text__set(self):
        self.tsub.main_text = "test"
        assert self.tsub.main_text == "test"

    def test_mode__get(self):
        assert self.tsub.mode == TIME
        assert self.fsub.mode == FRAME

    def test_mode__set_frame(self):
        self.fsub.mode = FRAME
        self.fsub.mode = TIME
        assert self.fsub._start == "00:00:04.000"
        assert self.fsub._end == "00:00:12.000"

    def test_mode__set_time(self):
        self.tsub.mode = TIME
        self.tsub.mode = FRAME
        assert self.tsub._start == 25
        assert self.tsub._end == 75

    def test_scale_positions__frame(self):
        self.fsub.scale_positions(2.0)
        assert self.fsub.start == 200
        assert self.fsub.end == 600

    def test_scale_positions__time(self):
        self.tsub.scale_positions(2.0)
        assert self.tsub.start == "00:00:02.000"
        assert self.tsub.end == "00:00:06.000"

    def test_set_text(self):
        self.tsub.set_text(MAIN, "")
        assert self.tsub.main_text == ""
        self.tsub.set_text(TRAN, "")
        assert self.tsub.tran_text == ""

    def test_shift_positions__frame(self):
        self.fsub.shift_positions(-10)
        assert self.fsub._start == 90
        assert self.fsub._end == 290

    def test_shift_positions__seconds(self):
        self.tsub.shift_positions(1.0)
        assert self.tsub._start == "00:00:02.000"
        assert self.tsub._end == "00:00:04.000"

    def test_shift_positions__time(self):
        self.tsub.shift_positions("00:00:01.000")
        assert self.tsub._start == "00:00:02.000"
        assert self.tsub._end == "00:00:04.000"

    def test_start__get(self):
        assert self.tsub.start == "00:00:01.000"
        assert self.fsub.start == 100

    def test_start__set_frame(self):
        self.fsub.start = 500
        assert self.fsub.start_frame == 500
        self.fsub.start = "00:00:10.000"
        assert self.fsub.start_frame == 250
        self.fsub.start = 5.0
        assert self.fsub.start_frame == 125

    def test_start__set_time(self):
        self.tsub.start = "00:00:10.000"
        assert self.tsub.start_time == "00:00:10.000"
        self.tsub.start = 500
        assert self.tsub.start_time == "00:00:20.000"
        self.tsub.start = 5.0
        assert self.tsub.start_time == "00:00:05.000"

    def test_start_frame__get(self):
        assert self.tsub.start_frame == 25
        assert self.fsub.start_frame == 100

    def test_start_frame__set(self):
        self.fsub.start_frame = 25
        assert self.fsub.start_frame == 25

    def test_start_seconds__get(self):
        assert self.tsub.start_seconds == 1.0
        assert self.fsub.start_seconds == 4.0

    def test_start_seconds__set(self):
        self.tsub.start_seconds = 0.1
        assert self.tsub.start_seconds == 0.1

    def test_start_time__get(self):
        assert self.tsub.start_time == "00:00:01.000"
        assert self.fsub.start_time == "00:00:04.000"

    def test_start_time__set(self):
        self.tsub.start_time = "00:00:00.100"
        assert self.tsub.start_time == "00:00:00.100"

    def test_tran_text__get(self):
        assert self.tsub.tran_text == "translation"
        assert self.fsub.tran_text == "translation"

    def test_tran_text_set(self):
        self.tsub.tran_text = "test"
        assert self.tsub.tran_text == "test"



# -*- coding: utf-8 -*-

# Copyright (C) 2006 Osmo Salomaa
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

import aeidon


class TestModule(aeidon.TestCase):

    def test_atomic_open__existing_file(self):
        path = self.new_subrip_file()
        with aeidon.util.atomic_open(path, "w") as f:
            f.write("test\n")
        text = open(path, "r").read()
        assert text == "test\n"

    def test_atomic_open__no_existing_file(self):
        path = aeidon.temp.create()
        with aeidon.util.atomic_open(path, "w") as f:
            f.write("test\n")
        text = open(path, "r").read()
        assert text == "test\n"

    def test_compare_versions(self):
        assert aeidon.util.compare_versions("0.1.1", "0.1"  ) ==  1
        assert aeidon.util.compare_versions("0.2"  , "0.1"  ) ==  1
        assert aeidon.util.compare_versions("0.3"  , "0.3"  ) ==  0
        assert aeidon.util.compare_versions("0.4"  , "0.4.1") == -1
        assert aeidon.util.compare_versions("0.4"  , "0.5"  ) == -1

    def test_detect_format(self):
        for format in aeidon.formats:
            path = self.new_temp_file(format)
            assert aeidon.util.detect_format(path, "ascii") == format

    def test_detect_newlines__mac(self):
        path = aeidon.temp.create()
        open(path, "w", newline="").write("a\rb\rc\r")
        newlines = aeidon.util.detect_newlines(path)
        assert newlines == aeidon.newlines.MAC

    def test_detect_newlines__unix(self):
        path = aeidon.temp.create()
        open(path, "w", newline="").write("a\nb\nc\n")
        newlines = aeidon.util.detect_newlines(path)
        assert newlines == aeidon.newlines.UNIX

    def test_detect_newlines__windows(self):
        path = aeidon.temp.create()
        open(path, "w", newline="").write("a\r\nb\r\nc\r\n")
        newlines = aeidon.util.detect_newlines(path)
        assert newlines == aeidon.newlines.WINDOWS

    def test_flatten(self):
        lst = [1, 2, [3, 4, [5, 6, [7]], 8], 9]
        lst = aeidon.util.flatten(lst)
        assert lst == [1, 2, 3, 4, 5, 6, 7, 8, 9]

    def test_get_default_encoding(self):
        assert aeidon.util.get_default_encoding()

    def test_get_default_newline(self):
        assert aeidon.util.get_default_newline()

    def test_get_encoding_alias(self):
        assert aeidon.util.get_encoding_alias("utf8") == "utf_8"
        assert aeidon.util.get_encoding_alias("johab") == "johab"

    def test_get_ranges(self):
        lst = [0, 0, 4, 5, 3, 7, 8, 2, 7]
        lst = aeidon.util.get_ranges(lst)
        assert lst == [[0], [2, 3, 4, 5], [7, 8]]

    def test_get_unique__first(self):
        lst = [4, 1, 5, 5, 1, 1, 3, 6, 4, 4]
        lst = aeidon.util.get_unique(lst)
        assert lst == [4, 1, 5, 3, 6]

    def test_get_unique__last(self):
        lst = [4, 1, 5, 5, 1, 1, 3, 6, 4, 4]
        lst = aeidon.util.get_unique(lst, keep_last=True)
        assert lst == [5, 1, 3, 6, 4]

    def test_read__basic(self):
        path = self.new_subrip_file()
        text = open(path, "r", encoding="ascii").read().strip()
        assert aeidon.util.read(path) == text

    def test_read__fallback(self):
        path = self.new_subrip_file()
        open(path, "w", encoding="utf_8").write("\xc3\xb6\n")
        assert aeidon.util.read(path, "ascii") == "\xc3\xb6"

    def test_readlines__basic(self):
        path = self.new_subrip_file()
        lines = [x.rstrip() for x in open(path, "r").readlines()]
        assert aeidon.util.readlines(path) == lines

    def test_readlines__fallback(self):
        path = self.new_subrip_file()
        open(path, "w", encoding="utf_8").write("\xc3\xb6\n")
        assert aeidon.util.readlines(path, "ascii") == ["\xc3\xb6"]

    def test_write__basic(self):
        text = "test\ntest\n"
        path = self.new_subrip_file()
        aeidon.util.write(path, text)
        f = open(path, "r", encoding="ascii")
        assert f.read() == text

    def test_write__fallback(self):
        text = "\xc3\xb6\n"
        path = self.new_subrip_file()
        aeidon.util.write(path, text, "ascii")
        f = open(path, "r", encoding="utf_8")
        assert f.read() == text

    def test_writelines__basic(self):
        lines = ("test", "test")
        path = self.new_subrip_file()
        aeidon.util.writelines(path, lines)
        f = open(path, "r", encoding="ascii")
        assert f.read() == "test\ntest\n"

    def test_writelines__fallback(self):
        text = "\xc3\xb6"
        path = self.new_subrip_file()
        aeidon.util.writelines(path, (text,), "ascii")
        f = open(path, "r", encoding="utf_8")
        assert f.read() == text + "\n"



# -*- coding: utf-8 -*-

# Copyright (C) 2005 Osmo Salomaa
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

import gaupol


class _TestFileDialog(gaupol.TestCase):

    def test_get_encoding(self):
        encoding = gaupol.conf.encoding.visible[0]
        self.dialog.set_encoding(encoding)
        assert self.dialog.get_encoding() == encoding
        self.dialog.set_encoding("johab")
        assert self.dialog.get_encoding() == "johab"

    def test_set_encoding(self):
        encoding = gaupol.conf.encoding.visible[0]
        self.dialog.set_encoding(encoding)
        assert self.dialog.get_encoding() == encoding
        self.dialog.set_encoding("utf_8")
        assert self.dialog.get_encoding() == "utf_8"



# -*- coding: utf-8 -*-

# Copyright (C) 2005 Osmo Salomaa
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

import aeidon


class TestSetAgent(aeidon.TestCase):

    def setup_method(self, method):
        self.project = self.new_project()

    @aeidon.deco.reversion_test
    def test_set_duration(self):
        subtitles = self.project.subtitles
        self.project.set_duration(0, "00:01:11.111")
        assert subtitles[0].duration_time == "00:01:11.111"

    @aeidon.deco.reversion_test
    def test_set_end(self):
        subtitles = self.project.subtitles
        self.project.set_end(0, 600000)
        assert subtitles[0].end_frame == 600000

    @aeidon.deco.reversion_test
    def test_set_main_text(self):
        subtitles = self.project.subtitles
        self.project.set_main_text(0, "m")
        assert subtitles[0].main_text == "m"

    @aeidon.deco.reversion_test
    def test_set_start(self):
        subtitles = self.project.subtitles
        self.project.set_start(0, -100.0)
        assert subtitles[0].start_seconds == -100.0

    @aeidon.deco.reversion_test
    def test_set_start__reorder(self):
        subtitles = self.project.subtitles
        text_0 = subtitles[0].main_text
        text_3 = subtitles[3].main_text
        self.project.set_start(3, -1000)
        assert subtitles[0].start_frame == -1000
        assert subtitles[0].main_text == text_3
        assert subtitles[1].main_text == text_0

    @aeidon.deco.reversion_test
    def test_set_text__main(self):
        subtitles = self.project.subtitles
        self.project.set_text(0, aeidon.documents.MAIN, "m")
        assert subtitles[0].main_text == "m"

    @aeidon.deco.reversion_test
    def test_set_text__translation(self):
        subtitles = self.project.subtitles
        self.project.set_text(0, aeidon.documents.TRAN, "t")
        assert subtitles[0].tran_text == "t"

    @aeidon.deco.reversion_test
    def test_set_translation_text(self):
        subtitles = self.project.subtitles
        self.project.set_translation_text(0, "t")
        assert subtitles[0].tran_text == "t"



# -*- coding: utf-8 -*-

# Copyright (C) 2005 Osmo Salomaa
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

import aeidon


class TestCalculator(aeidon.TestCase):

    def setup_method(self, method):
        self.framerate = aeidon.framerates.FPS_23_976
        self.calc = aeidon.Calculator(self.framerate)

    def test___new__(self):
        a = aeidon.Calculator(aeidon.framerates.FPS_23_976)
        b = aeidon.Calculator(aeidon.framerates.FPS_23_976)
        assert a is b

    def test___new____float(self):
        a = aeidon.Calculator(48.0)
        b = aeidon.Calculator(96.0)
        assert a is not b

    def test_add__frames(self):
        assert self.calc.add(10, 10) == 20

    def test_add__seconds(self):
        assert self.calc.add(10.0, 10.0) == 20.0

    def test_add__times(self):
        assert self.calc.add("00:00:10.000",
                             "00:00:10.000") == "00:00:20.000"

    def test_frame_to_seconds(self):
        calc = aeidon.Calculator(aeidon.framerates.FPS_25_000)
        assert calc.frame_to_seconds(127) == 5.08

    def test_frame_to_time(self):
        assert self.calc.frame_to_time(2658) == "00:01:50.861"

    def test_get_middle__frame(self):
        assert self.calc.get_middle(300, 400) == 350

    def test_get_middle__seconds(self):
        assert self.calc.get_middle(300.0, 400.0) == 350.0

    def test_get_middle__time(self):
        assert self.calc.get_middle("00:00:01.000",
                                    "00:00:02.000") == "00:00:01.500"

    def test_is_earlier__frame(self):
        assert self.calc.is_earlier(1, 2)
        assert not self.calc.is_earlier(2, 2)
        assert not self.calc.is_earlier(2, 1)

    def test_is_earlier__seconds(self):
        assert self.calc.is_earlier(1.0, 2.0)
        assert not self.calc.is_earlier(2.0, 2.0)
        assert not self.calc.is_earlier(2.0, 1.0)

    def test_is_earlier__time(self):
        assert self.calc.is_earlier("00:00:01.000", "00:00:02.000")
        assert not self.calc.is_earlier("00:00:01.000", "00:00:01.000")
        assert not self.calc.is_earlier("00:00:02.000", "00:00:01.000")

    def test_is_later__frame(self):
        assert self.calc.is_later(2, 1)
        assert not self.calc.is_later(2, 2)
        assert not self.calc.is_later(1, 2)

    def test_is_later__seconds(self):
        assert self.calc.is_later(2.0, 1.0)
        assert not self.calc.is_later(2.0, 2.0)
        assert not self.calc.is_later(1.0, 2.0)

    def test_is_later__time(self):
        assert self.calc.is_later("00:00:02.000", "00:00:01.000")
        assert not self.calc.is_later("00:00:02.000", "00:00:02.000")
        assert not self.calc.is_later("00:00:01.000", "00:00:02.000")

    def test_is_valid_time__false(self):
        assert not self.calc.is_valid_time("2:34:56.789")
        assert not self.calc.is_valid_time("12:60:56.789")

    def test_is_valid_time__true(self):
        assert self.calc.is_valid_time("12:34:56.789")
        assert self.calc.is_valid_time("-12:34:56.789")

    def test_normalize_time(self):
        assert self.calc.normalize_time("1:2:3.4") == "01:02:03.400"
        assert self.calc.normalize_time("-1:2:3,4") == "-01:02:03.400"
        assert self.calc.normalize_time("12:34.567") == "00:12:34.567"

    def test_round__frame(self):
        assert self.calc.round(13, -1) == 10

    def test_round__seconds(self):
        assert self.calc.round(13.33, 0) == 13.0

    def test_round__time(self):
        assert self.calc.round("12:34:56.789", 1) == "12:34:56.800"

    def test_seconds_to_frame(self):
        assert self.calc.seconds_to_frame(6552) == 157091

    def test_seconds_to_time(self):
        assert self.calc.seconds_to_time(68951.15388) == "19:09:11.154"

    def test_time_to_frame(self):
        assert self.calc.time_to_frame("01:22:36.144") == 118829

    def test_time_to_seconds(self):
        assert self.calc.time_to_seconds("03:45:22.117") == 13522.117

    def test_to_frame(self):
        self.calc = aeidon.Calculator(aeidon.framerates.FPS_25_000)
        assert self.calc.to_frame("00:00:01.000") == 25
        assert self.calc.to_frame(25) == 25
        assert self.calc.to_frame(1.0) == 25

    def test_to_seconds(self):
        self.calc = aeidon.Calculator(aeidon.framerates.FPS_25_000)
        assert self.calc.to_seconds("00:00:01.000") == 1.0
        assert self.calc.to_seconds(25) == 1.0
        assert self.calc.to_seconds(1.0) == 1.0

    def test_to_time(self):
        self.calc = aeidon.Calculator(aeidon.framerates.FPS_25_000)
        assert self.calc.to_time("00:00:01.000") == "00:00:01.000"
        assert self.calc.to_time(25) == "00:00:01.000"
        assert self.calc.to_time(1.0) == "00:00:01.000"



# -*- coding: utf-8 -*-

# Copyright (C) 2005 Osmo Salomaa
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

import aeidon

MAIN = aeidon.documents.MAIN
TRAN = aeidon.documents.TRAN


class TestSearchAgent(aeidon.TestCase):

    ######### 0000000000111111111122222222223333333333444444444
    ######### 0123456789012345678901234567890123456789012345678
    texts = ("God has promised you that\nyou will go to Heaven?",
             "So you are certain of\nbeing saved?",
             "Be careful,\nit's a dangerous answer.")

    def setup_method(self, method):
        self.project = self.new_project()
        for i, text in enumerate(self.texts):
            self.project.subtitles[i].main_text = text
            self.project.subtitles[i].tran_text = text
        indices = list(range(3, len(self.project.subtitles)))
        self.project.remove_subtitles(indices, register=None)

    def test_find_next(self):
        matches = iter(((0, MAIN, ( 0,  0)),
                        (0, MAIN, (26, 26)),
                        (1, MAIN, ( 0,  0)),
                        (1, MAIN, (22, 22)),
                        (2, MAIN, ( 0,  0)),
                        (2, MAIN, (12, 12)),
                        StopIteration))

        self.project.set_search_target(None, (MAIN,), wrap=False)
        self.project.set_search_regex(r"^")
        index, doc, pos = None, MAIN, None
        while True:
            try:
                index, doc, span = self.project.find_next(index, doc, pos)
                assert (index, doc, span) == next(matches)
                pos = span[1]
            except StopIteration:
                assert next(matches) is StopIteration
                break

    def test_find_previous(self):
        matches = iter(((1, MAIN, ( 3,  6)),
                        (0, MAIN, (26, 29)),
                        (0, MAIN, (17, 20)),
                        StopIteration))

        self.project.set_search_target(None, (MAIN,), wrap=False)
        self.project.set_search_string("you", ignore_case=False)
        index, doc, pos = None, MAIN, None
        while True:
            try:
                index, doc, span = self.project.find_previous(index, doc, pos)
                assert (index, doc, span) == next(matches)
                pos = span[0]
            except StopIteration:
                assert next(matches) is StopIteration
                break

    @aeidon.deco.reversion_test
    def test_replace(self):
        self.project.set_search_target(None, (MAIN,))
        self.project.set_search_regex(r"\b\s")
        self.project.set_search_replacement("")
        self.project.find_next(index=0, doc=MAIN, pos=4)
        self.project.replace()
        text = self.project.subtitles[0].main_text
        assert text == "God haspromised you that\nyou will go to Heaven?"

    @aeidon.deco.reversion_test
    def test_replace_all(self):
        self.project.set_search_target(None, (MAIN, TRAN))
        self.project.set_search_regex(r"$")
        self.project.set_search_replacement("--")
        self.project.replace_all()
        texts = ("God has promised you that--\nyou will go to Heaven?--",
                 "So you are certain of--\nbeing saved?--",
                 "Be careful,--\nit's a dangerous answer.--")

        for i, text in enumerate(texts):
            assert self.project.subtitles[i].main_text == text
            assert self.project.subtitles[i].tran_text == text



# -*- coding: utf-8 -*-

# Copyright (C) 2005 Osmo Salomaa
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

import aeidon
import codecs


class TestOpenAgent(aeidon.TestCase):

    def setup_method(self, method):
        self.project = self.new_project()

    def test_open_main(self):
        for format in aeidon.formats:
            path = self.new_temp_file(format)
            self.project.open_main(path, "ascii")
            assert self.project.subtitles

    def test_open_main__bom(self):
        path = self.new_subrip_file()
        blob = open(path, "rb").read()
        open(path, "wb").write(codecs.BOM_UTF8 + blob)
        self.project.open_main(path, "ascii")
        assert self.project.subtitles
        assert self.project.main_file.encoding == "utf_8_sig"

    def test_open_main__sort(self):
        path = self.new_microdvd_file()
        with open(path, "w") as f:
            f.write("{100}{200}\n")
            f.write("{500}{600}\n")
            f.write("{300}{400}\n")
        sort_count = self.project.open_main(path, "ascii")
        assert sort_count == 1

    def test_open_translation__align_number(self):
        for format in aeidon.formats:
            path = self.new_temp_file(format)
            method = aeidon.align_methods.NUMBER
            self.project.open_translation(path, "ascii", method)

    def test_open_translation__align_position(self):
        for format in aeidon.formats:
            path = self.new_temp_file(format)
            method = aeidon.align_methods.POSITION
            self.project.open_translation(path, "ascii", method)

    def test_open_translation__bom(self):
        path = self.new_subrip_file()
        blob = open(path, "rb").read()
        open(path, "wb").write(codecs.BOM_UTF8 + blob)
        self.project.open_translation(path, "ascii")
        assert self.project.subtitles
        assert self.project.tran_file.encoding == "utf_8_sig"



# -*- coding: utf-8 -*-

# Copyright (C) 2010 Osmo Salomaa
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

import aeidon
import gaupol
import os
import shutil


class TestConfigurationStore(gaupol.TestCase):

    def setup_method(self, method):
        self.conf = gaupol.ConfigurationStore()
        self.directory = aeidon.temp.create_directory()
        self.conf.path = os.path.join(self.directory, "test")

    def teardown_method(self, method):
        shutil.rmtree(self.directory)
        gaupol.TestCase.teardown_method(self, method)

    def test_read_from_file(self):
        self.conf.write_to_file()
        self.conf.restore_defaults()
        self.conf.read_from_file()

    def test_register_extension(self):
        defaults = dict(x=1, mode=aeidon.modes.TIME)
        enums = dict(mode=aeidon.modes)
        self.conf.register_extension("test", defaults, enums)
        assert self.conf.extensions.test.x == 1
        assert self.conf.extensions.test.mode == aeidon.modes.TIME

    def test_restore_defaults(self):
        size = list(self.conf.application_window.size)
        self.conf.application_window.size = [99, 99]
        self.conf.restore_defaults()
        assert self.conf.application_window.size == size

    def test_write_to_file(self):
        self.conf.write_to_file()
        self.conf.restore_defaults()
        self.conf.read_from_file()



# -*- coding: utf-8 -*-

# Copyright (C) 2005 Osmo Salomaa
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

import gaupol

from gi.repository import Gdk


class TestModule(gaupol.TestCase):

    def test_char_to_px(self):
        px1 = gaupol.util.char_to_px(1)
        px2 = gaupol.util.char_to_px(2)
        assert 2 < px1 < 10
        assert 4 < px2 < 20
        assert abs(2 * px1 - px2) <= 1

    def test_char_to_px__font(self):
        deft = gaupol.util.char_to_px(100)
        cust = gaupol.util.char_to_px(100, font="custom")
        mono = gaupol.util.char_to_px(100, font="monospace")
        assert 200 < deft < cust
        assert 200 < deft < mono

    def test_hex_to_rgba(self):
        color = gaupol.util.hex_to_rgba("#ff0000")
        assert color.equal(Gdk.RGBA(red=1, green=0, blue=0, alpha=1))

    def test_lines_to_px(self):
        px1 = gaupol.util.lines_to_px(1)
        px2 = gaupol.util.lines_to_px(2)
        assert 10 < px1 < 30
        assert 20 < px2 < 60
        assert abs(2 * px1 - px2) <= 1

    def test_lines_to_px__font(self):
        deft = gaupol.util.lines_to_px(10)
        cust = gaupol.util.lines_to_px(10, font="custom")
        mono = gaupol.util.lines_to_px(10, font="monospace")
        assert 50 < deft < 200
        assert 50 < cust < 200
        assert 50 < mono < 200

    def test_rgba_to_hex(self):
        rgba = Gdk.RGBA(red=1, green=0, blue=1)
        color = gaupol.util.rgba_to_hex(rgba)
        assert color == "#ff00ff"

    def test_tree_path_to_row(self):
        path = gaupol.util.tree_row_to_path(1)
        assert gaupol.util.tree_path_to_row(path) == 1
        assert gaupol.util.tree_path_to_row("1") == 1

    def test_tree_row_to_path(self):
        path = gaupol.util.tree_row_to_path(1)
        assert gaupol.util.tree_path_to_row(path) == 1



# -*- coding: utf-8 -*-

# Copyright (C) 2005 Osmo Salomaa
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

import aeidon


class TestEnumerationItem(aeidon.TestCase):

    def setup_method(self, method):
        self.parent = object()
        self.item_0 = aeidon.EnumerationItem(0, "a", self.parent)
        self.item_1 = aeidon.EnumerationItem(1, "b", self.parent)
        self.item_2 = aeidon.EnumerationItem(2, "c", self.parent)

    def test___bool__(self):
        assert self.item_0
        assert self.item_1
        assert self.item_2

    def test___eq__(self):
        assert self.item_0 == self.item_0
        assert self.item_0 == 0

    def test___ne__(self):
        assert self.item_0 != self.item_1
        assert self.item_0 != 1

    def test___str__(self):
        assert str(self.item_0) == "a"
        assert str(self.item_1) == "b"
        assert str(self.item_2) == "c"


class TestEnumeration(aeidon.TestCase):

    def setup_method(self, method):
        self.fruits = aeidon.Enumeration()
        self.fruits.APPLE = aeidon.EnumerationItem()
        self.fruits.MANGO = aeidon.EnumerationItem()
        self.fruits.APPLE.size = 10
        self.fruits.MANGO.size = 20

    def test___contains__(self):
        assert self.fruits.APPLE in self.fruits
        assert self.fruits.MANGO in self.fruits

    def test___delattr__(self):
        value = self.fruits.MANGO
        delattr(self.fruits, "MANGO")
        assert not hasattr(self.fruits, "MANGO")
        assert not value in self.fruits

    def test_find_item(self):
        assert self.fruits.find_item("size", 10) == self.fruits.APPLE
        assert self.fruits.find_item("size", 20) == self.fruits.MANGO

    def test___setattr__(self):
        assert self.fruits.APPLE == 0
        assert self.fruits.MANGO == 1
        assert self.fruits.APPLE.name == "APPLE"
        assert self.fruits.MANGO.name == "MANGO"
        assert self.fruits.APPLE.size == 10
        assert self.fruits.MANGO.size == 20



# -*- coding: utf-8 -*-

# Copyright (C) 2005 Osmo Salomaa
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

import gaupol


class TestViewAgent(gaupol.TestCase):

    def setup_method(self, method):
        self.application = self.new_application()

    def test__on_toggle_duration_column_toggled(self):
        name = "toggle-duration-column"
        self.application.get_action(name).activate()
        self.application.get_action(name).activate()

    def test__on_toggle_end_column_toggled(self):
        name = "toggle-end-column"
        self.application.get_action(name).activate()
        self.application.get_action(name).activate()

    def test__on_toggle_main_text_column_toggled(self):
        name = "toggle-main-text-column"
        self.application.get_action(name).activate()
        self.application.get_action(name).activate()

    def test__on_toggle_main_toolbar_toggled(self):
        name = "toggle-main-toolbar"
        self.application.get_action(name).activate()
        self.application.get_action(name).activate()

    def test__on_toggle_number_column_toggled(self):
        name = "toggle-number-column"
        self.application.get_action(name).activate()
        self.application.get_action(name).activate()

    def test__on_toggle_start_column_toggled(self):
        name = "toggle-start-column"
        self.application.get_action(name).activate()
        self.application.get_action(name).activate()

    def test__on_toggle_translation_text_column_toggled(self):
        name = "toggle-translation-text-column"
        self.application.get_action(name).activate()
        self.application.get_action(name).activate()



# -*- coding: utf-8 -*-

# Copyright (C) 2005 Osmo Salomaa
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

import gaupol
import os

from gi.repository import Gtk
from gaupol.dialogs.test.test_file import _TestFileDialog


class TestAppendDialog(_TestFileDialog):

    def run_dialog(self):
        self.dialog.run()

    def setup_method(self, method):
        gaupol.conf.file.directory = os.getcwd()
        self.dialog = gaupol.AppendDialog(Gtk.Window())
        self.dialog.show()



# -*- coding: utf-8 -*-

# Copyright (C) 2005 Osmo Salomaa
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

import gaupol

from gi.repository import Gtk


class _TestMessageDialog(gaupol.TestCase):

    def run_dialog(self):
        self.dialog.run()
        self.dialog.destroy()


class TestErrorDialog(_TestMessageDialog):

    def setup_method(self, method):
        self.dialog = gaupol.ErrorDialog(Gtk.Window(), "test", "test")
        self.dialog.add_button("_OK", Gtk.ResponseType.OK)
        self.dialog.set_default_response(Gtk.ResponseType.OK)
        self.dialog.show()


class TestInfoDialog(_TestMessageDialog):

    def setup_method(self, method):
        self.dialog = gaupol.InfoDialog(Gtk.Window(), "test", "test")
        self.dialog.add_button("_OK", Gtk.ResponseType.OK)
        self.dialog.set_default_response(Gtk.ResponseType.OK)
        self.dialog.show()


class TestQuestionDialog(_TestMessageDialog):

    def setup_method(self, method):
        self.dialog = gaupol.QuestionDialog(Gtk.Window(), "test", "test")
        self.dialog.add_button("_No", Gtk.ResponseType.NO)
        self.dialog.add_button("_Yes", Gtk.ResponseType.YES)
        self.dialog.set_default_response(Gtk.ResponseType.YES)
        self.dialog.show()


class TestWarningDialog(_TestMessageDialog):

    def setup_method(self, method):
        self.dialog = gaupol.WarningDialog(Gtk.Window(), "test", "test")
        self.dialog.add_button("_OK", Gtk.ResponseType.OK)
        self.dialog.set_default_response(Gtk.ResponseType.OK)
        self.dialog.show()



# -*- coding: utf-8 -*-

# Copyright (C) 2007 Osmo Salomaa
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

import aeidon

from aeidon.i18n import d_


class TestModule(aeidon.TestCase):

    def test_code_to_name(self):
        name = d_("iso_15924", "Arabic")
        assert aeidon.scripts.code_to_name("Arab") == name
        name = d_("iso_15924", "Latin")
        assert aeidon.scripts.code_to_name("Latn") == name

    def test_is_valid(self):
        assert aeidon.scripts.is_valid("Latn")
        assert not aeidon.scripts.is_valid("Xxxx")



# -*- coding: utf-8 -*-

# Copyright (C) 2005 Osmo Salomaa
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

import aeidon
import re


class TestParser(aeidon.TestCase):

    def setup_method(self, method):
        self.parser = aeidon.Parser(re.compile(r"<.+?>"),
                                    lambda x: x.strip())

    def test_get_text__margins(self):
        text = ("<i>You will find allies there,</i>\n"
                "<i>and they will pay more.</i>")

        self.parser.set_text(text)
        assert self.parser.get_text() == text

    def test_get_text__tags(self):
        text = ("<i>You will find allies there,</i>\n"
                "<i>and</i> they <i>will pay more.</i>")

        self.parser.set_text(text)
        assert self.parser.get_text() == text

    def test_replace_all__regex(self):
        text = ("<i>One only risks it, <b>because</b>\n"
                "one's survival depends on it.</i>")

        self.parser.set_text(text)
        self.parser.set_regex(r"\b")
        self.parser.replacement = "-"
        self.parser.replace_all()
        assert self.parser.get_text() == (
            "<i>-One- -only- -risks- -it-, <b>-because-</b>\n"
            "-one-'-s- -survival- -depends- -on- -it-.</i>")

    def test_replace_all__string(self):
        text = ("<i>One only risks it, <b>because</b>\n"
                "one's survival depends on it.</i>")

        self.parser.set_text(text)
        self.parser.pattern = "e"
        self.parser.replacement = ""
        self.parser.replace_all()
        assert self.parser.get_text() == (
            "<i>On only risks it, <b>bcaus</b>\n"
            "on's survival dpnds on it.</i>")

    def test_set_text__margins(self):
        text = ("<i>One only risks it, because</i>\n"
                "<i>one's survival depends on it.</i>")

        self.parser.set_text(text)
        assert self.parser.text == (
            "One only risks it, because\n"
            "one's survival depends on it.")

    def test_set_text__tags(self):
        text = ("<i>One only risks it, <b>because</b>\n"
                "one's survival depends on it.</i>")

        self.parser.set_text(text)
        assert self.parser.text == (
            "One only risks it, because\n"
            "one's survival depends on it.")



# -*- coding: utf-8 -*-

# Copyright (C) 2005 Osmo Salomaa
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

import aeidon


class TestSaveAgent(aeidon.TestCase):

    def setup_method(self, method):
        self.project = self.new_project()

    def test_save_main(self):
        for format in aeidon.formats:
            self.project.clear_texts((0,), aeidon.documents.MAIN)
            path = self.project.main_file.path
            file = aeidon.files.new(format, path, "ascii")
            self.project.save_main(file, keep_changes=False)
            assert self.project.main_changed == 1
            file = aeidon.files.new(format, path, "ascii")
            self.project.save_main(file, keep_changes=True)
            assert self.project.main_changed == 0

    def test_save_translation(self):
        for format in aeidon.formats:
            self.project.clear_texts((0,), aeidon.documents.TRAN)
            path = self.project.tran_file.path
            file = aeidon.files.new(format, path, "ascii")
            self.project.save_translation(file, keep_changes=False)
            assert self.project.tran_changed == 1
            self.project.save_translation(file, keep_changes=True)
            assert self.project.tran_changed == 0



# -*- coding: utf-8 -*-

# Copyright (C) 2006 Osmo Salomaa
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

import gaupol

from gi.repository import Gtk


class TestSearchDialog(gaupol.TestCase):

    def run_dialog(self):
        self.dialog.run()
        self.dialog.destroy()

    def run__show_regex_error_dialog_pattern(self):
        self.dialog._show_regex_error_dialog_pattern("test")

    def run__show_regex_error_dialog_replacement(self):
        self.dialog._show_regex_error_dialog_replacement("test")

    def setup_method(self, method):
        self.application = self.new_application()
        self.dialog = gaupol.SearchDialog(
            self.application.window, self.application)
        self.dialog.show()

    def test_next(self):
        self.dialog._regex_check.set_active(True)
        for char in "aeiouy":
            self.dialog._pattern_entry.set_text(char)
            self.dialog.next()
            self.dialog.next()

    def test__on_application_page_changed(self):
        # Ensure that editing obsolete data is not possible.
        # https://bugzilla.gnome.org/show_bug.cgi?id=572676
        self.dialog._pattern_entry.set_text("a")
        self.dialog.next()
        page = self.application.get_current_page()
        page.project.remove_subtitles((self.dialog._match_row,))
        assert not self.dialog._text_view.get_sensitive()
        assert not self.dialog._replace_button.get_sensitive()

    def test__on_response(self):
        self.dialog.response(Gtk.ResponseType.HELP)

    def test_previous(self):
        self.dialog._regex_check.set_active(True)
        for char in "aeiouy":
            self.dialog._pattern_entry.set_text(char)
            self.dialog.previous()
            self.dialog.previous()

    def test_replace(self):
        self.dialog._regex_check.set_active(True)
        for char in "aeiouy":
            self.dialog._pattern_entry.set_text(char)
            self.dialog._replacement_entry.set_text("x")
            self.dialog.next()
            self.dialog.replace()
            self.dialog.replace()

    def test_replace_all(self):
        self.dialog._regex_check.set_active(True)
        self.dialog._pattern_entry.set_text("^")
        self.dialog._replacement_entry.set_text("-")
        self.dialog.replace_all()



# -*- coding: utf-8 -*-

# Copyright (C) 2006 Osmo Salomaa
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

import aeidon


class TestModule(aeidon.TestCase):

    def setup_method(self, method):
        self.project = self.new_project()

    def test_silent(self):
        function = lambda: 0 / 0
        aeidon.deco.silent(ZeroDivisionError)(function)()
        aeidon.deco.silent(ZeroDivisionError, tb=True)(function)()
        aeidon.deco.silent(Exception)(function)()
        aeidon.deco.silent(Exception, tb=True)(function)()



# -*- coding: utf-8 -*-

# Copyright (C) 2005 Osmo Salomaa
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

import gaupol
import sys


class TestDebugDialog(gaupol.TestCase):

    def run_dialog(self):
        self.dialog.run()
        self.dialog.destroy()

    def setup_method(self, method):
        self.dialog = gaupol.DebugDialog()
        try:
            self.dialog.foo()
        except AttributeError:
            self.dialog.set_text(*sys.exc_info())
        self.dialog.show()
